import { ICaptionTrack } from "./ICaptionTrack";
import { ISubtitle } from "./ISubtitle";
import { IVideoData } from "./IVideoData";
/**
 * Youtube Caption Retriever
 *
 * Note: All Requests are locally cached
 * @export
 * @class YoutubeCaption
 */
export declare class YoutubeCaption {
    readonly videoId: string;
    private _video_info;
    private _subtitles;
    /**
     * Creates an instance of YoutubeCaption
     * @param {string} videoId - The Youtube VideoId
     * @memberof YoutubeCaption
     */
    constructor(videoId: string);
    /**
     * Retrieve a list of Caption Tracks
     *
     * @returns {Promise<ICaptionTrack[]>}
     * @memberof YoutubeCaption
     */
    getCaptionTracks(): Promise<ICaptionTrack[]>;
    /**
     * Retrieve Subtitles
     *
     * @param {string} [lang] - language to retrieve, defaults to en
     * @returns {Promise<ISubtitle[]>}
     * @memberof YoutubeCaption
     */
    getSubtitles(lang?: string): Promise<ISubtitle[]>;
    /**
     * Retrieve Video Info as an object
     *
     * @returns {Promise<any>}
     * @memberof YoutubeCaption
     */
    getVideoInfoObject(): Promise<IVideoData>;
    /**
     * Retrieve Video Info
     *
     * @private
     * @returns {Promise<string>}
     * @memberof YoutubeCaption
     */
    private getVideoInfo;
    /**
     * Parse and Convert XML string to JSON
     *
     * @private
     * @param {string} xml
     * @returns {Promise<any>}
     * @memberof YoutubeCaption
     */
    private parseString;
}
