import { ICaptionTrack } from "./ICaptionTrack";
import { ISubtitle } from "./ISubtitle";
import { IVideoData } from "./IVideoData";
import { YoutubeCaption } from "./YoutubeCaption";
export { YoutubeCaption, ISubtitle, ICaptionTrack, IVideoData };
interface ISubtitleOptions {
    videoID: string;
    lang?: "en" | "de" | "fr" | "es" | "ru" | "it";
}
/**
 * Retrieves Subtitles for certain youtube video
 *
 * @export
 * @param {ISubtitleOptions} {
 * 	videoID,
 * 	lang = 'en',
 * }
 * @returns {Promise<ISubtitle[]} subtitles
 */
export declare function getSubtitles({ videoID, lang }: ISubtitleOptions): Promise<ISubtitle[]>;
/**
 * Retrieves Information about certain video
 *
 * @export
 * @param {ISubtitleOptions} {
 * 	videoID,
 * }
 * @returns {Promise<ISubtitle[]} subtitles
 */
export declare function getVideoInfo({ videoID }: ISubtitleOptions): Promise<IVideoData>;
/**
 * Retrieves Subtitles for certain youtube video
 *
 * @export
 * @param {ISubtitleOptions} {
 * 	videoID,
 * 	lang = 'en',
 * }
 * @returns {string} subtitles
 */
export declare function getSubtitlesContent({ videoID, lang }: ISubtitleOptions): Promise<string>;
