"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const YoutubeCaption_1 = require("./YoutubeCaption");
exports.YoutubeCaption = YoutubeCaption_1.YoutubeCaption;
/**
 * Retrieves Subtitles for certain youtube video
 *
 * @export
 * @param {ISubtitleOptions} {
 * 	videoID,
 * 	lang = 'en',
 * }
 * @returns {Promise<ISubtitle[]} subtitles
 */
async function getSubtitles({ videoID, lang = "en" }) {
    const youtubeCaptions = new YoutubeCaption_1.YoutubeCaption(videoID);
    return await youtubeCaptions.getSubtitles(lang);
}
exports.getSubtitles = getSubtitles;
/**
 * Retrieves Information about certain video
 *
 * @export
 * @param {ISubtitleOptions} {
 * 	videoID,
 * }
 * @returns {Promise<ISubtitle[]} subtitles
 */
async function getVideoInfo({ videoID }) {
    const youtubeCaptions = new YoutubeCaption_1.YoutubeCaption(videoID);
    return await youtubeCaptions.getVideoInfoObject();
}
exports.getVideoInfo = getVideoInfo;
/**
 * Retrieves Subtitles for certain youtube video
 *
 * @export
 * @param {ISubtitleOptions} {
 * 	videoID,
 * 	lang = 'en',
 * }
 * @returns {string} subtitles
 */
async function getSubtitlesContent({ videoID, lang = "en" }) {
    const subtitles = await getSubtitles({ videoID, lang });
    let content = "";
    for (const subtitle of subtitles) {
        content += " " + subtitle.text;
    }
    return content.replace(/([\s\r\n])+/g, " ");
}
exports.getSubtitlesContent = getSubtitlesContent;
//# sourceMappingURL=index.js.map